classdef ProcNoiseExperiment < falcon.core.Handle
    % -------------------------------------------------------------------------
    %                                FALCON.m
    % Copyright (c) 2014-2019 Institute of Flight System Dynamics, TUM, Munich
    % Matthias Bittner, Matthias Rieck, Maximilian Richter,
    % Benedikt Grueter, Johannes Diepolder, Florian Schwaiger,
    % Patrick Piprek, and Florian Holzapfel
    % Downloading, using, copying, or modifying FALCON.m code constitutes an
    % agreement to ALL of the terms of the FALCON.m EULA.
    % -------------------------------------------------------------------------

    % -------------------------------------------------------------------------
    %                                FALCON.m
    % Copyright (c) 2014-2019 Institute of Flight System Dynamics, TUM, Munich
    % Matthias Bittner, Matthias Rieck, Maximilian Richter,
    % Benedikt Grueter, Johannes Diepolder, Florian Schwaiger,
    % Patrick Piprek, and Florian Holzapfel
    % Downloading, using, copying, or modifying FALCON.m code constitutes an
    % agreement to ALL of the terms of the FALCON.m EULA.
    % -------------------------------------------------------------------------

    properties
        % factor to decrease the process noise sample time in order to
        % reduce number of variables, and make process noise better
        % identifiable. Process noise will be interpolated to fit
        % integration time steps; a factor < 1 is interpreted as percentage
        % of original samples to be kept. a factor > 1 is interpreted as
        % explicit number of samples to retain
        ProcNoiseSampleTimeFactor
        % size of process noise vector
        nW
        % falcon.parest.core.ProcNoiseExperiment/wfreeIdx is a property.
        wfreeIdx
        % falcon.parest.core.ProcNoiseExperiment/nWfree is a property.
        nWfree
        % sample size of the process noise, sampled down by
        % falcon.parest.Experiment.ProcNoiseSampleTimeFactor
        Nprocnoise
        % numericla values of the process noise of the model
        ProcessNoiseValues
        % falcon.parest.core.ProcNoiseExperiment/ProcessNoiseNames is a property.
        ProcessNoiseNames
        % falcon.parest.core.ProcNoiseExperiment/ProcessNoiseTime is a property.
        ProcessNoiseTime
        % numericla values of the process noise of the model, interpolated
        % to match the state grid
        StateInterpolatedProcessNoiseValues
        % numericla values of the process noise of the model, interpolated
        % to match the state grid
        OutputInterpolatedProcessNoiseValues
        % The process noise covariance matrix for a filter formulatoin
        Q
        % the initial state covariance matrix in a filter formulation
        P_xx_0
        % flag to indicate, if experiment has process noise input
        hasProcessNoise
        % falcon.parest.core.ProcNoiseExperiment/ProcessNoiseUpperBound is a property.
        ProcessNoiseUpperBound
        % falcon.parest.core.ProcNoiseExperiment/ProcessNoiseLowerBound is a property.
        ProcessNoiseLowerBound
        % falcon.parest.core.ProcNoiseExperiment/ProcessNoiseScaling is a property.
        ProcessNoiseScaling
        % the measurement noise covariance matrix in a filter formulatoin
        R
        % the outputs to consider in a filter formulation
        ConsideredOutputs
        % flag indicating if smoother is to be used
        SmootherFlag
        % the process noise feed-through matrix in a filter formulation
        E
        % the process noise of this experiment
        w
        % falcon.parest.core.ProcNoiseExperiment/ProcNoiseSplineMatrix_raw is a property.
        ProcNoiseSplineMatrix_raw
        % falcon.parest.core.ProcNoiseExperiment/ProcNoiseSplineMatrix_fine is a property.
        ProcNoiseSplineMatrix_fine
    end

    methods
        function makeProcNoiseInitialGuess(obj, varargin)
        % MAKEPROCNOISEINITIALGUESS make initial guess for process noise
        %  
        %  	<Syntax>
        %  	makeProcNoiseInitialGuess( obj )
        %  
        %  	<Description>
        %  	make intial guess for process noise terms. Use initial
        %  	state guess to compute initial state derivatives, and
        %  	assign process noise such, that all integration defects are
        %  	initially at a minimum. This is done using an OLS solution.
        %   !!!!!!!!!! the process noise computede here may violate
        %   its boundaries! however, they will be enforced by the
        %   optimizer !!!!!!!!
        %  
        %  	<Inputs>
        %  	>obj: the falcon.parest.Experiment object
        %  
        %  	<ChangeLog>
        %  	2018-06-26 - Ch. Goettlicher: commenting
        end

        function setFilterData(obj, varargin)
        % SETFILTERDATA set the additional data, necessary for the filter
        %  
        %   <Syntax>
        %   obj.setFilterData( R, Q, P_xx_0)
        %   obj.setFilterData( R, Q, P_xx_0, ConsideredOutputs)
        %   obj.setFilterData( R, Q, P_xx_0, ConsideredOutputs, E)
        %  
        %   <Description>
        %  	store the filter data and afterwards call the checkFilterData
        %  	method in order to verify, that all dimensions etc. are
        %  	proper
        %  
        %  	<Inputs>
        %  	>obj: the Experiment object
        %  	>Q: process noise covariance matrix
        %  	>R: measurement noise covariance matrix
        %  	>P_xx_0: initial state covariance matrix
        %  
        %  	<NameValue>
        %  	>ConsideredOutputs: logical array indicating, which outputs
        %  	to use. default is all outputs. can also be string
        %  	'Outputs', then the model's output's 'isConsidered'
        %  	configuration is used.
        %  	>E: process noise feedthrough matrix
        %  
        %  	<ChangeLog>
        %  	2017-02-11 - Ch. Goettlicher: initial design
        %  	2017-12-19 - Ch. Goettlicher: commenting (-->EMT completion)
        end

        function obj = ProcNoiseExperiment()
        % -------------------------------------------------------------------------
        %                                FALCON.m
        % Copyright (c) 2014-2019 Institute of Flight System Dynamics, TUM, Munich
        % Matthias Bittner, Matthias Rieck, Maximilian Richter,
        % Benedikt Grueter, Johannes Diepolder, Florian Schwaiger,
        % Patrick Piprek, and Florian Holzapfel
        % Downloading, using, copying, or modifying FALCON.m code constitutes an
        % agreement to ALL of the terms of the FALCON.m EULA.
        % -------------------------------------------------------------------------
        end

    end

end