classdef SplineInterpolation < falcon.core.Handle
    % FALCON.PAREST.CORE.SPLINEINTERPOLATION utility functions for splines
    %  
    %  	<Description>
    %  	this class implements spline interpolation from a coarse to a fine
    %  	grid of output and output sensitivity data, based on the spline
    %  	collocation matrices
    %  
    %  	<ChangeLog>
    %  	2017-12-19 - Ch. Goettlicher: commenting (-->EMT completion)

    % -------------------------------------------------------------------------
    %                                FALCON.m
    % Copyright (c) 2014-2019 Institute of Flight System Dynamics, TUM, Munich
    % Matthias Bittner, Matthias Rieck, Maximilian Richter,
    % Benedikt Grueter, Johannes Diepolder, Florian Schwaiger,
    % Patrick Piprek, and Florian Holzapfel
    % Downloading, using, copying, or modifying FALCON.m code constitutes an
    % agreement to ALL of the terms of the FALCON.m EULA.
    % -------------------------------------------------------------------------

    properties
    end

    methods
        function dy_dp_fine = dy_dp(dy_dp_in, SplineMatrix_fine, SplineMatrix_raw)
        % DY_DP spline interpolate output sensitivities
        %  
        %  	<Syntax>
        %  	[ dy_dp_fine ] = SplineInterpolation.dy_dp( dy_dp_in, SplineMatrix_fine, SplineMatrix_raw )
        %  
        %  	<Description>
        %  	spline interpolate the model's output sensitivities dy/dp
        %  	onto a finer grid via the two spline matrices. First the
        %  	spline coefficients from the coarse grid are determined,
        %  	after which the fine grid data is obtained.
        %  	since the sensitivity data is 3 dimensional, several
        %  	permutations have to be done, in order to obtain the proper
        %  	dimensionalities
        %  
        %  	<Inputs>
        %  	>dy_dp_in: cell array of output sensitivities on a coarse
        %  	grid
        %  	>SplineMatrix_fine: sparse matrix to map spline coefficients
        %  	onto fine grid
        %  	>SplineMatrix_raw: sparse matrix to map spline coefficients
        %  	onto coarse grid
        %  
        %  	<Outputs>
        %  	>dy_dp_fine: cell array of interpolated model output
        %  	sensitivities
        %  
        %  	<ChangeLog>
        %  	2017-01-31 - Ch. Goettlicher: initial design
        %  	2017-12-19 - Ch. Goettlicher: commenting (-->EMT completion)
        end

        function val_fine = y(val_in, SplineMatrix_fine, SplineMatrix_raw)
        % Y spline interpolate model outputs
        %  
        %  	<Syntax>
        %  	[ y_fine ] = SplineInterpolation.y( y_in, SplineMatrix_fine, SplineMatrix_raw )
        %  
        %  	<Description>
        %  	spline interpolate the model outputs y onto a finer grid via
        %  	the two spline matrices. First the spline coefficients from
        %  	the coarse grid are determined, after which the fine grid
        %  	data is obtained.
        %  
        %  	<Inputs>
        %  	>y_in: cell array of model output values on a coarse grid
        %  	>SplineMatrix_fine: sparse matrix to map spline coefficients
        %  	onto fine grid
        %  	>SplineMatrix_raw: sparse matrix to map spline coefficients
        %  	onto coarse grid
        %  
        %  	<Outputs>
        %  	>y_fine: cell array of interpolated model output values
        %  
        %  	<ChangeLog>
        %  	2017-01-31 - Ch. Goettlicher: initial design
        %  	2017-12-19 - Ch. Goettlicher: commenting (-->EMT completion)
        end

        function obj = SplineInterpolation()
        % FALCON.PAREST.CORE.SPLINEINTERPOLATION utility functions for splines
        %  
        %  	<Description>
        %  	this class implements spline interpolation from a coarse to a fine
        %  	grid of output and output sensitivity data, based on the spline
        %  	collocation matrices
        %  
        %  	<ChangeLog>
        %  	2017-12-19 - Ch. Goettlicher: commenting (-->EMT completion)
        end

    end

end