classdef hasCovariance < falcon.core.Handle
    % HASCOVARIANCE Summary of this class goes here
    %   Detailed explanation goes here

    % -------------------------------------------------------------------------
    %                                FALCON.m
    % Copyright (c) 2014-2019 Institute of Flight System Dynamics, TUM, Munich
    % Matthias Bittner, Matthias Rieck, Maximilian Richter,
    % Benedikt Grueter, Johannes Diepolder, Florian Schwaiger,
    % Patrick Piprek, and Florian Holzapfel
    % Downloading, using, copying, or modifying FALCON.m code constitutes an
    % agreement to ALL of the terms of the FALCON.m EULA.
    % -------------------------------------------------------------------------

    properties
        % standard deviation of this parameter
        StandardDeviation
        % relativ standard deviation, i.e. sigma/value
        RelStandardDeviation
    end

    methods
        function Correlation = getCorrelation(obj)
        % GETCORRELATION get correlation matrix for an array of
        %   parameters
        %  
        %  	<Syntax>
        %  	[ Correlation ] = getCorrelation( obj )
        %  
        %  	<Description>
        %  	get the correlation matrix for an array of parameters. It is
        %  	computed from falcon.parest.Parameter.getCovariance and the
        %  	corresponding standard deviations
        %  
        %  	<Inputs>
        %  	>obj: the Parameter object
        %  
        %  	<Outputs>
        %  	>Correlation: correlation matrix
        %  
        %  	<ChangeLog>
        %  	2017-01-28 - Ch. Goettlicher: initial design
        %  	2017-12-19 - Ch. Goettlicher: commenting (-->EMT completion)
        end

        function setVariances(obj, CrossVariance, varargin)
        % SETVARIANCES set parameter variances
        %  
        %  	<Syntax>
        %  	setVariances( obj, CrossVariance, CrossVarianceParameters )
        %  
        %  	<Description>
        %  	store the cross variances with other parameters. Both the
        %  	cross variances and the respective parameters are stored.
        %  	However these two arrays are sorted such, that the first
        %  	entry always is the parameter itself, i.e. the first
        %  	covariance is the parameter variance.
        %  
        %  	<Inputs>
        %  	>obj: the Parameter object
        %  	>CrossVariance: double array of cross variance parameters
        %  	>CrossVarianceParameters: Parameter objects which are
        %  	associated with the corresponding entries in the
        %  	CrossVariance input
        %  
        %  	<ChangeLog>
        %  	2017-01-28 - Ch. Goettlicher: initial design
        %  	2017-12-19 - Ch. Goettlicher: commenting (-->EMT completion)
        end

        function Covariance = getCovariance(obj)
        % GETCOVARIANCE get covariance matrix of a parameter array
        %  
        %  	<Syntax>
        %  	[ Covariance ] = getCovariance( obj )
        %  
        %  	<Description>
        %  	obtain the covariance matrix for an array of parameters. to
        %  	do so, the Cross-Variance-Parameters are compared to the
        %  	parameter array (obj), and the covariance matrix is built up
        %  	from the cross variances
        %  
        %  	<Inputs>
        %  	>obj: the Parameter object
        %  
        %  	<Outputs>
        %  	>Covariance: Covariance matrix for this array of parameters
        %  
        %  	<ChangeLog>
        %  	2017-01-28 - Ch. Goettlicher: initial design
        %  	2017-12-19 - Ch. Goettlicher: commenting (-->EMT completion)
        end

        function obj = hasCovariance()
        % HASCOVARIANCE Summary of this class goes here
        %   Detailed explanation goes here
        end

    end

end