classdef B777LatSystemDynamic < matlab.System
    %ACTLATSYSTEMDYNAMIC system dynamics for lateral directional AC motion
    
    %#codegen
    
    properties
        % trim conditions
        gamma_0 = 0;
        alpha_0 = 0;
        V_0 = 264;
        g = 9.8166;
    end
    
    methods (Access=protected)
        function [r_dot, beta_dot, p_dot, phi_dot] = stepImpl(Obj, r, beta, p, phi, xi, zeta, N_r, N_beta, N_p, N_xi, N_zeta, Y_r, Y_beta, Y_p, Y_xi, Y_zeta, L_r, L_beta, L_p, L_xi, L_zeta)
            % initial pitch angle
            theta_0 = Obj.alpha_0 + Obj.gamma_0;
            
            u = [xi; zeta];
            x = [r; beta; p; phi];
            
            A = [
                N_r,                  N_beta, N_p,                  0; ...
                Y_r-cos(Obj.alpha_0), Y_beta, Y_p+sin(Obj.alpha_0), Obj.g/Obj.V_0*cos(Obj.alpha_0); ...
                L_r,                  L_beta, L_p,                  0; ...
                tan(theta_0),         0,      1,                    0];
            B = [
                N_xi, N_zeta;
                Y_xi, Y_zeta;
                L_xi, L_zeta;
                0,      0;
                ];
            
            x_dot = A*x + B*u;
            
            r_dot = x_dot(1);
            beta_dot = x_dot(2);
            p_dot = x_dot(3);
            phi_dot = x_dot(4);
        end
    end
end

